/* BigList.java */

/* 
 * Copyright (C) 1996-97 Mark Boyns <boyns@sdsu.edu>
 *
 * This file is part of Muffin.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package muffin;

import java.awt.Dimension;
import java.awt.List;

/**
 * @author Mark Boyns
 */
class BigList extends List
{
    BigList (int rows, boolean mult)
    {
	super (rows, mult);
    }
	
    public Dimension getPreferredSize ()
    {
	return new Dimension (200, 150);
    }

    public Dimension getPreferredSize (int rows)
    {
	return new Dimension (200, 150);
    }

    public Dimension getMinimumSize ()
    {
	return new Dimension (200, 150);
    }

    public Dimension getMinimumSize (int rows)
    {
	return new Dimension (200, 150);
    }
}
